@@ -4,14 +4,6 @@ except ImportError:
     from urlparse import urljoin
 
 
-try:
-    import email.utils
-    parsedate_tz = email.utils.parsedate_tz
-except ImportError:
-    import email.Utils
-    parsedate_tz = email.Utils.parsedate_tz
-
-
 try:
     import cPickle as pickle
 except ImportError:
